<?php

return [

  'routes' => [
    'enabled' => true,
    'api' => [
      'group' => ['prefix' => 'api/v1/auth'],
      'guard' => 'auth:api',
      'register' => [
        'email' => [
          'uses' => '\Myriad\Authentication\Http\Controllers\RegistrationController@register',
          'as' => 'users.register'
        ]
      ],
      'login' => [
        'email' => [
          'uses' => '\Myriad\Authentication\Http\Controllers\LoginController@login',
          'as' => 'users.login'
        ]
      ],
      'me' => [
        'uses' => '\Myriad\Authentication\Http\Controllers\UserController@me',
        'as' => 'users.me'
      ],
      'verification_code' => [
        'verify' => [
          'uses' => '\Myriad\Authentication\Http\Controllers\VerificationCodeController@verify',
          'as' => 'verification_code.verify'
        ],
        'send' => [
          'uses' => '\Myriad\Authentication\Http\Controllers\VerificationCodeController@send',
          'as' => 'verification_code.send'
        ]
      ]
    ]
  ],

  'table_names' => [
    'users' => env('AUTHENTICATION_USERS_TABLE_NAME', 'users'),
    'user_phones' => env('AUTHENTICATION_USER_PHONES_TABLE_NAME', 'user_phones'),
    'user_emails' => env('AUTHENTICATION_USER_EMAILS_TABLE_NAME', 'user_emails'),
    'verification_codes' => env('AUTHENTICATION_VERIFICATION_CODES_TABLE_NAME', 'verification_codes'),
    'access_tokens' => env('AUTHENTICATION_ACCESS_TOKENS_TABLE_NAME', 'access_tokens'),
  ],

  'user_model' => Myriad\Authentication\Models\User::class,
  'user_repository' => Myriad\Authentication\Lib\Repositories\EloquentUserRepository::class,
  'user_transformer' => Myriad\Authentication\Http\Transformers\UserTransformer::class,

  'morph_map' => [
    'user' => '\Myriad\Authentication\Models\User'
  ],

  'verification_code_expiration_minutes' => env('VERIFICATION_CODE_EXPIRATION_MINUTES', 5),
  'access_token_expiration_days' => env('AUTHENTICATION_ACCESS_TOKEN_EXPIRATION_DAYS', 365),

  'event_listeners' => [
    'user_registered_with_email' => [
      '\Myriad\Authentication\Lib\Listeners\UserRegisteredWithEmailListener'
    ],
    'user_registered_with_phone' => [
      //TODO: add listener
    ]
  ],

  'email' => [
    'app_name' => 'Application',
    'templates' => [
      'email_address_verification' => [
        'subject' => 'Please verify your email address',
        'template' => 'authentication::email.auth.email_verification'
      ]
    ]
  ],

  'verification_strategies' => [
    'email' => '\Myriad\Authentication\Lib\Strategies\EmailVerification',
    'phone' => '\Myriad\Authentication\Lib\Strategies\PhoneNumberVerification',
  ]
];
