<?php

namespace Myriad\Authentication\Http\Controllers;

use Illuminate\Routing\Controller;
use Illuminate\Http\Request;
use Illuminate\Contracts\Bus\Dispatcher;
use Myriad\Authentication\Lib\Jobs\VerifyVerificationCode;
use Myriad\Authentication\Lib\Repositories\IAccessTokenRepository;
use Myriad\Installations\InstallationManager;
use Illuminate\Support\Facades\Validator;
use Illuminate\Contracts\Validation\ValidationException;
use Myriad\Authentication\Lib\Services\IEmailConfirmer;
use Illuminate\Contracts\Auth\Guard;
use Myriad\Authentication\Lib\Services\IPhoneNumberConfirmer;

class VerificationCodeController extends Controller {

  public function send(
    Request $request,
    Guard $guard,
    IEmailConfirmer $emailConfirmer,
    IPhoneNumberConfirmer $phoneNumberConfirmer
  ) {
    $validator = Validator::make($request->all(), [
      'email' => 'email|required_without:phone',
      'phone' => 'string|required_without:email'
    ]);

    if ($validator->fails()) {
      throw new ValidationException($validator);
    }

    $attributes['primary'] = !$guard->check();

    //TODO: move these to jobs
    if ($request->has('email')) {
      $emailConfirmer->sendConfirmationEmail(
        $request->email,
        $guard->user(),
        $attributes
      );
    } else {
      $phoneNumberConfirmer->sendConfirmationTextMessage(
        $request->phone,
        $guard->user(),
        $attributes
      );
    }
  }

  public function verify(
    Request $request,
    Dispatcher $busDispatcher,
    IAccessTokenRepository $accessTokenRepository,
    InstallationManager $manager
  ) {
    $user = $busDispatcher->dispatchNow(new VerifyVerificationCode($request->all()));

    if ($user) {
      $installation = $manager->getInstallation();
      $accessToken = $accessTokenRepository->createAccessToken($user, $installation);

      return [
        'data' => [
          'access_token' => $accessToken->token,
          'expires_at' => $accessToken->expires_at->toIso8601String()
        ]
      ];
    }

    //TODO: handle case when verification failed

  }

}
